==> roundcubemail-1.3.5.tgz: roundcubemail/program/js/tinymce/langs/eu.js <==
tinymce.addI18n('eu',{
"Cut": "Ebaki",
"Heading 5": "5. izenburua",
"Header 2": "2 Goiburua",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Zure nabigatzaileak ez du arbela zuzenean erabiltzeko euskarririk. Mesedez erabili CTRL+X\/C\/V teklatuko lasterbideak.",
"Heading 4": "4. izenburua",
"Div": "Div",
"Heading 2": "2. izenburua",
"Paste": "Itsatsi",
"Close": "Itxi",
"Font Family": "Letra-tipo familia",
"Pre": "Pre",
"Align right": "Lerrokatu eskuinean",
"New document": "Dokumentu berria",
"Blockquote": "Blockquote",
"Numbered list": "Zerrenda  zenbatua",
"Heading 1": "1. izenburua",
"Headings": "Izenburuak",
"Increase indent": "Handitu koska",
"Formats": "Formatuak",
"Headers": "Goiburuak",
"Select all": "Hautatu dena",
"Header 3": "3 Goiburua",
"Blocks": "Blokeak",
"Undo": "Desegin",
"Strikethrough": "Marratua",
"Bullet list": "Bulet zerrenda",
"Header 1": "1 Goiburua",
"Superscript": "Goi-indize",
"Clear formatting": "Garbitu formatua",
"Font Sizes": "Letra-tamainak",
"Subscript": "Azpiindize",
"Header 6": "6 Goiburua",
"Redo": "Berregin",
"Paragraph": "Paragrafoa",
"Ok": "Ondo",
"Bold": "Lodia",
"Code": "Kodea",
"Italic": "Etzana",
"Align center": "Lerrokatu erdian",
"Header 5": "5 Goiburua",
"Heading 6": "6. izenburua",
"Heading 3": "3. izenburua",
"Decrease indent": "Txikitu koska",
"Header 4": "4 Goiburua",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Itsatsi testu arrunt moduan dago orain. Edukiak testu arruntak bezala itsatsiko dira aukera hau itzaltzen duzunera arte.",
"Underline": "Azpimarratua",
"Cancel": "Ezeztatu",
"Justify": "Justifikatuta",
"Inline": "Lerroan",
"Copy": "Kopiatu",
"Align left": "Lerrokatu ezkerrean",
"Visual aids": "Laguntza bisualak",
"Lower Greek": "Behe grekoa",
"Square": "Karratua",
"Default": "Lehenetstia",
"Lower Alpha": "Behe alfa",
"Circle": "Zirkulua",
"Disc": "Diskoa",
"Upper Alpha": "Goi alfa",
"Upper Roman": "Goi erromatarra",
"Lower Roman": "Behe erromatarra",
"Name": "Izena",
"Anchor": "Esteka",
"You have unsaved changes are you sure you want to navigate away?": "Gorde gabeko aldaketak dituzu, zihur zaude hemendik irten nahi duzula?",
"Restore last draft": "Leheneratu azken zirriborroa",
"Special character": "Karaktere bereziak",
"Source code": "Iturburu-kodea",
"B": "B",
"R": "R",
"G": "G",
"Color": "Kolorea",
"Right to left": "Eskuinetik ezkerrera",
"Left to right": "Ezkerretik eskuinera",
"Emoticons": "Irrifartxoak",
"Robots": "Robotak",
"Document properties": "Dokumentuaren propietateak",
"Title": "Titulua",
"Keywords": "Hitz gakoak",
"Encoding": "Encoding",
"Description": "Deskribapena",
"Author": "Egilea",
"Fullscreen": "Pantaila osoa",
"Horizontal line": "Marra horizontala",
"Horizontal space": "Hutsune horizontala",
"Insert\/edit image": "Irudia txertatu\/editatu",
"General": "Orokorra",
"Advanced": "Aurreratua",
"Source": "Iturburua",
"Border": "Ertza",
"Constrain proportions": "Zerraditu proportzioak",
"Vertical space": "Hutsune bertikala",
"Image description": "Irudiaren deskribapena",
"Style": "Estiloa",
"Dimensions": "Neurriak",
"Insert image": "Irudia txertatu",
"Zoom in": "Zoom in",
"Contrast": "Contrast",
"Back": "Back",
"Gamma": "Gamma",
"Flip horizontally": "Flip horizontally",
"Resize": "Resize",
"Sharpen": "Sharpen",
"Zoom out": "Zoom out",
"Image options": "Image options",
"Apply": "Apply",
"Brightness": "Brightness",
"Rotate clockwise": "Rotate clockwise",
"Rotate counterclockwise": "Rotate counterclockwise",
"Edit image": "Edit image",
"Color levels": "Color levels",
"Crop": "Crop",
"Orientation": "Orientation",
"Flip vertically": "Flip vertically",
"Invert": "Invert",
"Insert date\/time": "Data\/ordua txertatu",
"Remove link": "Kendu esteka",
"Url": "Url",
"Text to display": "Bistaratzeko testua",
"Anchors": "Estekak",
"Insert link": "Esteka txertatu",
"New window": "Lehio berria",
"None": "Bat ere ez",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Sartu duzun URL-ak kanpoko esteka dela dirudi. Nahi duzu dagokion http:\/\/ aurrizkia gehitzea?",
"Target": "Target",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Sartu duzun URL-ak e-posta helbidea dela dirudi. Nahi duzu dagokion mailto: aurrizkia gehitzea?",
"Insert\/edit link": "Esteka txertatu\/editatu",
"Insert\/edit video": "Bideoa txertatu\/editatu",
"Poster": "Poster-a",
"Alternative source": "Iturburu alternatiboa",
"Paste your embed code below:": "Itsatsi hemen zure enkapsulatzeko kodea:",
"Insert video": "Bideoa txertatu",
"Embed": "Kapsulatu",
"Nonbreaking space": "Zuriune zatiezina",
"Page break": "Orrialde-jauzia",
"Paste as text": "Itsatsi testu bezala",
"Preview": "Aurrebista",
"Print": "Inprimatu",
"Save": "Gorde",
"Could not find the specified string.": "Ezin izan da zehaztutako katea aurkitu.",
"Replace": "Ordeztu",
"Next": "Hurrengoa",
"Whole words": "hitz osoak",
"Find and replace": "Bilatu eta ordeztu",
"Replace with": "Honekin ordeztu",
"Find": "Bilatu",
"Replace all": "Ordeztu dena",
"Match case": "Maiuskula\/minuskula",
"Prev": "Aurrekoa",
"Spellcheck": "Egiaztapenak",
"Finish": "Amaitu",
"Ignore all": "Ez ikusi guztia",
"Ignore": "Ez ikusi",
"Add to Dictionary": "Gehitu hiztegira",
"Insert row before": "Txertatu errenkada aurretik",
"Rows": "Errenkadak",
"Height": "Altuera",
"Paste row after": "Itsatsi errenkada ostean",
"Alignment": "Lerrokatzea",
"Border color": "Bordearen kolorea",
"Column group": "Zutabe taldea",
"Row": "Errenkada",
"Insert column before": "Txertatu zutabe aurretik",
"Split cell": "Banatu gelaxkak",
"Cell padding": "Gelaxken betegarria",
"Cell spacing": "Gelaxka arteko tartea",
"Row type": "Lerro mota",
"Insert table": "Txertatu taula",
"Body": "Gorputza",
"Caption": "Epigrafea",
"Footer": "Oina",
"Delete row": "Ezabatu errenkada",
"Paste row before": "Itsatsi errenkada aurretik",
"Scope": "Esparrua",
"Delete table": "Taula ezabatu",
"H Align": "Lerrokatze horizontala",
"Top": "Goian",
"Header cell": "Goiburuko gelaxka",
"Column": "Zutabea",
"Row group": "Lerro taldea",
"Cell": "Gelaxka",
"Middle": "Erdian",
"Cell type": "Gelaxka mota",
"Copy row": "Kopiatu errenkada",
"Row properties": "Errenkadaren propietateak",
"Table properties": "Taularen propietateak",
"Bottom": "Behean",
"V Align": "Lerrokatze bertikala",
"Header": "Goiburua",
"Right": "Eskuina",
"Insert column after": "Txertatu zutabea ostean",
"Cols": "Zutabeak",
"Insert row after": "Txertatu errenkada ostean",
"Width": "Zabalera",
"Cell properties": "Gelaxkaren propietateak",
"Left": "Ezkerra",
"Cut row": "Ebaki errenkada",
"Delete column": "Ezabatu zutabea",
"Center": "Erdia",
"Merge cells": "Batu gelaxkak",
"Insert template": "Txertatu txantiloia",
"Templates": "Txantiloiak",
"Background color": "Atzeko kolorea",
"Custom...": "Pertsonalizatua...",
"Custom color": "Kolore pertsonalizatua",
"No color": "Kolorerik gabe",
"Text color": "Testuaren kolorea",
"Show blocks": "Erakutsi blokeak",
"Show invisible characters": "Erakutsi karaktere izkutuak",
"Words: {0}": "Hitzak: {0}",
"Insert": "Sartu",
"File": "Fitxategia",
"Edit": "Editatu",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Testu aberastuko area. Sakatu ALT-F9 menurako. Sakatu ALT-F10 tresna-barrarako. Sakatu ALT-0 laguntzarako",
"Tools": "Tresnak",
"View": "Ikusi",
"Table": "Taula",
"Format": "Formatua"
});

==> roundcubemail-1.4.11p0.tgz: roundcubemail/program/js/tinymce/langs/eu.js <==
tinymce.addI18n('eu',{
"Redo": "Berregin",
"Undo": "Desegin",
"Cut": "Ebaki",
"Copy": "Kopiatu",
"Paste": "Itsatsi",
"Select all": "Hautatu dena",
"New document": "Dokumentu berria",
"Ok": "Ondo",
"Cancel": "Ezeztatu",
"Visual aids": "Laguntza bisualak",
"Bold": "Lodia",
"Italic": "Etzana",
"Underline": "Azpimarratua",
"Strikethrough": "Marratua",
"Superscript": "Goi-indize",
"Subscript": "Azpiindize",
"Clear formatting": "Garbitu formatua",
"Align left": "Lerrokatu ezkerrean",
"Align center": "Lerrokatu erdian",
"Align right": "Lerrokatu eskuinean",
"Justify": "Justifikatuta",
"Bullet list": "Bulet zerrenda",
"Numbered list": "Zerrenda  zenbatua",
"Decrease indent": "Txikitu koska",
"Increase indent": "Handitu koska",
"Close": "Itxi",
"Formats": "Formatuak",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Zure nabigatzaileak ez du arbela zuzenean erabiltzeko euskarririk. Mesedez erabili CTRL+X\/C\/V teklatuko lasterbideak.",
"Headers": "Goiburuak",
"Header 1": "1 Goiburua",
"Header 2": "2 Goiburua",
"Header 3": "3 Goiburua",
"Header 4": "4 Goiburua",
"Header 5": "5 Goiburua",
"Header 6": "6 Goiburua",
"Headings": "Izenburuak",
"Heading 1": "1. izenburua",
"Heading 2": "2. izenburua",
"Heading 3": "3. izenburua",
"Heading 4": "4. izenburua",
"Heading 5": "5. izenburua",
"Heading 6": "6. izenburua",
"Preformatted": "Aurreformateatuta",
"Div": "Div",
"Pre": "Pre",
"Code": "Kodea",
"Paragraph": "Paragrafoa",
"Blockquote": "Blockquote",
"Inline": "Lerroan",
"Blocks": "Blokeak",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Itsatsi testu arrunt moduan dago orain. Edukiak testu arruntak bezala itsatsiko dira aukera hau itzaltzen duzunera arte.",
"Font Family": "Letra-tipo familia",
"Font Sizes": "Letra-tamainak",
"Class": "Klasea",
"Browse for an image": "Irudia arakatu",
"OR": "EDO",
"Drop an image here": "Irudia hona ekarri",
"Upload": "Kargatu",
"Block": "Blokea",
"Align": "Alineatu",
"Default": "Lehenetstia",
"Circle": "Zirkulua",
"Disc": "Diskoa",
"Square": "Karratua",
"Lower Alpha": "Behe alfa",
"Lower Greek": "Behe grekoa",
"Lower Roman": "Behe erromatarra",
"Upper Alpha": "Goi alfa",
"Upper Roman": "Goi erromatarra",
"Anchor": "Esteka",
"Name": "Izena",
"Id": "Id",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Ida hizki batekin hasi behar da, jarraian hizkiak, zenbakiak, gidoiak, puntuak, bi-puntu edo azpiko marrak bakarrik izan ditzake.",
"You have unsaved changes are you sure you want to navigate away?": "Gorde gabeko aldaketak dituzu, zihur zaude hemendik irten nahi duzula?",
"Restore last draft": "Leheneratu azken zirriborroa",
"Special character": "Karaktere bereziak",
"Source code": "Iturburu-kodea",
"Insert\/Edit code sample": "Txertatu\/editatu kode adibidea",
"Language": "Hizkuntza",
"Code sample": "Kode adibidea",
"Color": "Kolorea",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Ezkerretik eskuinera",
"Right to left": "Eskuinetik ezkerrera",
"Emoticons": "Irrifartxoak",
"Document properties": "Dokumentuaren propietateak",
"Title": "Titulua",
"Keywords": "Hitz gakoak",
"Description": "Deskribapena",
"Robots": "Robotak",
"Author": "Egilea",
"Encoding": "Encoding",
"Fullscreen": "Pantaila osoa",
"Action": "Akzioa",
"Shortcut": "Laster tekla",
"Help": "Laguntza",
"Address": "Helbidea",
"Focus to menubar": "Fokoa menu-barrara eraman",
"Focus to toolbar": "Fokoa tresna-barrara eraman",
"Focus to element path": "Fokoa elementuaren bidera eraman",
"Focus to contextual toolbar": "Fokoa kontestuko tresna-barrara eraman",
"Insert link (if link plugin activated)": "Lotura txertatu (lotura plugina aktibatuta badago)",
"Save (if save plugin activated)": "Gorde (gordetzeko plugina aktibatuta badago)",
"Find (if searchreplace plugin activated)": "Bilatu (bilatuordezkatu plugina instalatuta badago)",
"Plugins installed ({0}):": "Instalatutako pluginak ({0}):",
"Premium plugins:": "Premium pluginak:",
"Learn more...": "Gehiago ikasi...",
"You are using {0}": "{0} erabiltzen ari zara",
"Plugins": "Pluginak",
"Handy Shortcuts": "Laster-tekla erabilgarriak",
"Horizontal line": "Marra horizontala",
"Insert\/edit image": "Irudia txertatu\/editatu",
"Image description": "Irudiaren deskribapena",
"Source": "Iturburua",
"Dimensions": "Neurriak",
"Constrain proportions": "Zerraditu proportzioak",
"General": "Orokorra",
"Advanced": "Aurreratua",
"Style": "Estiloa",
"Vertical space": "Hutsune bertikala",
"Horizontal space": "Hutsune horizontala",
"Border": "Ertza",
"Insert image": "Irudia txertatu",
"Image": "Irudia",
"Image list": "Irudi zerrenda",
"Rotate counterclockwise": "Erlojuaren aurkako eran biratu",
"Rotate clockwise": "Erlojuaren eran biratu",
"Flip vertically": "Bertikalki irauli",
"Flip horizontally": "Horizontalki irauli",
"Edit image": "Irudia editatu",
"Image options": "Irudiaren aukerak",
"Zoom in": "Zooma handiagotu",
"Zoom out": "Zooma txikiagotu",
"Crop": "Moztu",
"Resize": "Tamaina aldatu",
"Orientation": "Orientazioa",
"Brightness": "Distira",
"Sharpen": "Zorroztu",
"Contrast": "Kontrastatu",
"Color levels": "Kolore mailak",
"Gamma": "Gamma",
"Invert": "Biratu",
"Apply": "Gorde",
"Back": "Atzera",
"Insert date\/time": "Data\/ordua txertatu",
"Date\/time": "Data\/ordua",
"Insert link": "Esteka txertatu",
"Insert\/edit link": "Esteka txertatu\/editatu",
"Text to display": "Bistaratzeko testua",
"Url": "Url",
"Target": "Target",
"None": "Bat ere ez",
"New window": "Lehio berria",
"Remove link": "Kendu esteka",
"Anchors": "Estekak",
"Link": "Lotura",
"Paste or type a link": "Itsatsu edo idatzi lotura",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Sartu duzun URL-ak e-posta helbidea dela dirudi. Nahi duzu dagokion mailto: aurrizkia gehitzea?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Sartu duzun URL-ak kanpoko esteka dela dirudi. Nahi duzu dagokion http:\/\/ aurrizkia gehitzea?",
"Link list": "Loturen zerrenda",
"Insert video": "Bideoa txertatu",
"Insert\/edit video": "Bideoa txertatu\/editatu",
"Insert\/edit media": "Media txertatu\/editatu",
"Alternative source": "Iturburu alternatiboa",
"Poster": "Poster-a",
"Paste your embed code below:": "Itsatsi hemen zure enkapsulatzeko kodea:",
"Embed": "Kapsulatu",
"Media": "Media",
"Nonbreaking space": "Zuriune zatiezina",
"Page break": "Orrialde-jauzia",
"Paste as text": "Itsatsi testu bezala",
"Preview": "Aurrebista",
"Print": "Inprimatu",
"Save": "Gorde",
"Find": "Bilatu",
"Replace with": "Honekin ordeztu",
"Replace": "Ordeztu",
"Replace all": "Ordeztu dena",
"Prev": "Aurrekoa",
"Next": "Hurrengoa",
"Find and replace": "Bilatu eta ordeztu",
"Could not find the specified string.": "Ezin izan da zehaztutako katea aurkitu.",
"Match case": "Maiuskula\/minuskula",
"Whole words": "hitz osoak",
"Spellcheck": "Egiaztapenak",
"Ignore": "Ez ikusi",
"Ignore all": "Ez ikusi guztia",
"Finish": "Amaitu",
"Add to Dictionary": "Hiztegira gehitu",
"Insert table": "Txertatu taula",
"Table properties": "Taularen propietateak",
"Delete table": "Taula ezabatu",
"Cell": "Gelaxka",
"Row": "Errenkada",
"Column": "Zutabea",
"Cell properties": "Gelaxkaren propietateak",
"Merge cells": "Batu gelaxkak",
"Split cell": "Banatu gelaxkak",
"Insert row before": "Txertatu errenkada aurretik",
"Insert row after": "Txertatu errenkada ostean",
"Delete row": "Ezabatu errenkada",
"Row properties": "Errenkadaren propietateak",
"Cut row": "Ebaki errenkada",
"Copy row": "Kopiatu errenkada",
"Paste row before": "Itsatsi errenkada aurretik",
"Paste row after": "Itsatsi errenkada ostean",
"Insert column before": "Txertatu zutabe aurretik",
"Insert column after": "Txertatu zutabea ostean",
"Delete column": "Ezabatu zutabea",
"Cols": "Zutabeak",
"Rows": "Errenkadak",
"Width": "Zabalera",
"Height": "Altuera",
"Cell spacing": "Gelaxka arteko tartea",
"Cell padding": "Gelaxken betegarria",
"Caption": "Epigrafea",
"Left": "Ezkerra",
"Center": "Erdia",
"Right": "Eskuina",
"Cell type": "Gelaxka mota",
"Scope": "Esparrua",
"Alignment": "Lerrokatzea",
"H Align": "Lerrokatze horizontala",
"V Align": "Lerrokatze bertikala",
"Top": "Goian",
"Middle": "Erdian",
"Bottom": "Behean",
"Header cell": "Goiburuko gelaxka",
"Row group": "Lerro taldea",
"Column group": "Zutabe taldea",
"Row type": "Lerro mota",
"Header": "Goiburua",
"Body": "Gorputza",
"Footer": "Oina",
"Border color": "Inguruko marraren kolorea",
"Insert template": "Txertatu txantiloia",
"Templates": "Txantiloiak",
"Template": "Txantiloia",
"Text color": "Testuaren kolorea",
"Background color": "Atzeko kolorea",
"Custom...": "Pertsonalizatu",
"Custom color": "Pertsonalizatutako kolorea",
"No color": "Kolorerik ez",
"Table of Contents": "Edukien taula",
"Show blocks": "Erakutsi blokeak",
"Show invisible characters": "Erakutsi karaktere izkutuak",
"Words: {0}": "Hitzak: {0}",
"{0} words": "{0} hitz",
"File": "Fitxategia",
"Edit": "Editatu",
"Insert": "Sartu",
"View": "Ikusi",
"Format": "Formatua",
"Table": "Taula",
"Tools": "Tresnak",
"Powered by {0}": "{0}rekin egina",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Testu aberastuko area. Sakatu ALT-F9 menurako. Sakatu ALT-F10 tresna-barrarako. Sakatu ALT-0 laguntzarako"
});
